@@ -218,11 +218,11 @@ class BaseController extends ActionController
      *********************************************/
 
     /**
-     * Action for Standard Searchbox
+     * Action for Standard Search
      */
     public function searchAction()
     {
-        // this fix multilanguge sites
+
         $shows = '0';
         if($this->settings['show']) {
             if (is_array($this->settings['show']))
@@ -232,82 +232,112 @@ class BaseController extends ActionController
             if (is_int($this->settings['show']))
                 $shows = (string)$this->settings['show'];
         }
-        //$cacheIdentifier = 'search_' . $this->settings['search']['layout'] . '_' . $shows . '_' . $this->settings['search']['layout'] . '_L' . $this->getLanguageUid();
-        ////$cacheIdentifier = strtolower($this->settings['search']['layout']).'_search_' . $this->filter->getCacheIdentifier();
+        $cacheIdentifier = 'search_' . $this->settings['search']['layout'] . '_' . $shows . '_' . $this->settings['search']['layout'] . '_L' . $this->getLanguageUid();
 
-        //if (($entry = $this->cache->get($cacheIdentifier)) === false) {
-        if ($this->settings['preset']['search']['filterData'] != 0) {
-            $kindOfObjectUids = explode(',', $this->settings['search']['kindOfObjects']);
-            foreach ($kindOfObjectUids as $kindOfObjectUid) {
-                $kindOfObject = $this->objektartRepository->findByUid($kindOfObjectUid);
-                if ($kindOfObject instanceof Objektart) {
-                    $this->filter->addObjektart($kindOfObject);
+        if (($entry = $this->cache->get($cacheIdentifier)) === false) {
+            if ($this->settings['preset']['search']['filterData'] != 0) {
+                $kindOfObjectUids = explode(',', $this->settings['search']['kindOfObjects']);
+                foreach ($kindOfObjectUids as $kindOfObjectUid) {
+                    $kindOfObject = $this->objektartRepository->findByUid($kindOfObjectUid);
+                    if ($kindOfObject instanceof Objektart) {
+                        $this->filter->addObjektart($kindOfObject);
+                    }
                 }
-            }
 
-            if (isset($this->settings['importids']) && $this->settings['importids'] != '') {
-                $arrayOfImportIds = explode(',', $this->settings['importids']);
-                if (is_array($arrayOfImportIds) && count($arrayOfImportIds) >= 1) {
-                    $this->filter->setImportIds($arrayOfImportIds);
+                if (isset($this->settings['importids']) && $this->settings['importids'] != '') {
+                    $arrayOfImportIds = explode(',', $this->settings['importids']);
+                    if (is_array($arrayOfImportIds) && count($arrayOfImportIds) >= 1) {
+                        $this->filter->setImportIds($arrayOfImportIds);
+                    } else {
+                        $this->filter->setImportIds([]);
+                    }
                 } else {
-                    $this->filter->setImportIds([]);
+                    $arrayOfImportIds = null;
                 }
-            } else {
-                $arrayOfImportIds = null;
-            }
 
-            if ($this->settings['preset']['search']['useSlider'] == 1) {
-                // BEGIN: Assign Values for Slider-Configuration to View
-                $this->view->assign('sizeSliderData', $this->getSizeSliderData());
-                $this->view->assign('roomSliderData', $this->getRoomSliderData());
-                $this->view->assign('amountSliderData', $this->getAmountSliderData());
-                // END: Assign Values for Slider-Configuration to View
-            }
-
-            $this->view->assign('regionOptions', $this->regionRepository->getAllForFilter($arrayOfImportIds));
-            $this->view->assign('districtOptions', $this->stadtteilRepository->getAllForFilter($this->settings['preset']['search']['districtFormat'], $arrayOfImportIds));
-            $this->view->assign('cityOptions', $this->ortRepository->getAllForFilter($arrayOfImportIds));
-            $this->view->assign('groupedCitiesAndDistricts', $this->ortRepository->getGroupedCitiesAndDistrictsForFilter($arrayOfImportIds));
-            $this->view->assign('filter', $this->filter);
-            $this->view->assign('cities', $this->ortRepository->findAll());
-
-
-            $this->view->assign('aggregatedFilterData', json_encode($this->getAggregatedFilterData()));
-            $this->view->assign('citiesAndDistrictsForFilter', json_encode($this->generateCityAndDistrictStructureForFilter()));
-
-            if ($this->settings['preset']['search']['simpleRealtyData'] == 1){
-                $returnArray = $this->immobilieRepository->findAllWithFilterData();
-                $realtiesModifited = $returnArray['realties'];
-                $this->view->assign('places', $returnArray['cities']);
-            }
-            else {
-                $realties = $this->immobilieRepository->findAllWithFilter($this->filter);
-                $this->view->assign('presets', $this->generateFilterPresetsFromResult($realties));
-
-                $this->view->assign('realties', $realties);
-                $realtiesModifited = array();
-                foreach ($realties as $k => $v) {
-                    $realtiesModifited[$k]['anzahlZimmer'] = $v->getAnzahlZimmer();
-                    $realtiesModifited[$k]['vermietbareFlaeche'] = $v->getVermietbareFlaeche();
-                    $realtiesModifited[$k]['kaltmiete'] = $v->getKaltmiete();
-                    $realtiesModifited[$k]['objektOrt'] = is_null($v->getObjektOrt()) ? '' : 'region-' . $v->getObjektOrt()->getUid();
-                    $realtiesModifited[$k]['objektStadtteil'] = is_null($v->getObjektStadtteil()) ? '' : 'district-' . $v->getObjektStadtteil()->getUid();
+                if ($this->settings['preset']['search']['useSlider'] == 1) {
+                    // BEGIN: Assign Values for Slider-Configuration to View
+                    $this->view->assign('sizeSliderData', $this->getSizeSliderData());
+                    $this->view->assign('roomSliderData', $this->getRoomSliderData());
+                    $this->view->assign('amountSliderData', $this->getAmountSliderData());
+                    // END: Assign Values for Slider-Configuration to View
                 }
+
+                $this->view->assign('regionOptions', $this->regionRepository->getAllForFilter($arrayOfImportIds));
+                $this->view->assign('districtOptions', $this->stadtteilRepository->getAllForFilter($this->settings['preset']['search']['districtFormat'], $arrayOfImportIds));
+                $this->view->assign('cityOptions', $this->ortRepository->getAllForFilter($arrayOfImportIds));
+                $this->view->assign('groupedCitiesAndDistricts', $this->ortRepository->getGroupedCitiesAndDistrictsForFilter($arrayOfImportIds));
+                $this->view->assign('filter', $this->filter);
+                $this->view->assign('cities', $this->ortRepository->findAll());
+
+
+                $this->view->assign('aggregatedFilterData', json_encode($this->getAggregatedFilterData()));
+                $this->view->assign('citiesAndDistrictsForFilter', json_encode($this->generateCityAndDistrictStructureForFilter()));
+
+                if ($this->settings['preset']['search']['simpleRealtyData'] == 1){
+                    $returnArray = $this->immobilieRepository->findAllWithFilterData();
+                    $realtiesModifited = $returnArray['realties'];
+                    $this->view->assign('places', $returnArray['cities']);
+                }
+                else {
+                    $realties = $this->immobilieRepository->findAllWithFilter($this->filter);
+                    $this->view->assign('presets', $this->generateFilterPresetsFromResult($realties));
+
+                    $this->view->assign('realties', $realties);
+                    $realtiesModifited = array();
+                    foreach ($realties as $k => $v) {
+                        $realtiesModifited[$k]['anzahlZimmer'] = $v->getAnzahlZimmer();
+                        $realtiesModifited[$k]['vermietbareFlaeche'] = $v->getVermietbareFlaeche();
+                        $realtiesModifited[$k]['kaltmiete'] = $v->getKaltmiete();
+                        $realtiesModifited[$k]['objektOrt'] = is_null($v->getObjektOrt()) ? '' : 'region-' . $v->getObjektOrt()->getUid();
+                        $realtiesModifited[$k]['objektStadtteil'] = is_null($v->getObjektStadtteil()) ? '' : 'district-' . $v->getObjektStadtteil()->getUid();
+                    }
+                }
+                $this->view->assign('realtiesModifited', $realtiesModifited);
             }
-            $this->view->assign('realtiesModifited', $realtiesModifited);
+
+            $entry = $this->view->render();
+
+            $tags = ['search'];
+            $lifetime = $this->settings['defaultCacheLifetime'];
+
+            // Save value in cache
+            $this->cache->set($cacheIdentifier, $entry, $tags, $lifetime);
         }
-
-        $entry = $this->view->render();
-
-        $tags = ['search'];
-        $lifetime = $this->settings['defaultCacheLifetime'];
-
-        // Save value in cache
-        //$this->cache->set($cacheIdentifier, $entry, $tags, $lifetime);
-        //}
         return $entry;
     }
 
+    /**
+     * Action for Standard Searchbox
+     */
+    public function searchboxAction()
+    {
+        $kindOfObjectUids = explode(',', $this->settings['search']['kindOfObjects']);
+        foreach ($kindOfObjectUids as $kindOfObjectUid) {
+            $kindOfObject = $this->objektartRepository->findByUid($kindOfObjectUid);
+            if ($kindOfObject instanceof Objektart) {
+                $this->filter->addObjektart($kindOfObject);
+            }
+        }
+        if (isset($this->settings['importids']) && $this->settings['importids'] != '') {
+            $arrayOfImportIds = explode(',', $this->settings['importids']);
+            if (is_array($arrayOfImportIds) && count($arrayOfImportIds) >= 1) {
+                $this->filter->setImportIds($arrayOfImportIds);
+            } else {
+                $this->filter->setImportIds([]);
+            }
+        } else {
+            $arrayOfImportIds = null;
+        }
+        $this->view->assign('regionOptions', $this->regionRepository->getAllForFilter($arrayOfImportIds));
+        $this->view->assign('districtOptions', $this->stadtteilRepository->getAllForFilter($this->settings['preset']['search']['districtFormat'], $arrayOfImportIds));
+        $this->view->assign('cityOptions', $this->ortRepository->getAllForFilter($arrayOfImportIds));
+        $this->view->assign('groupedCitiesAndDistricts', $this->ortRepository->getGroupedCitiesAndDistrictsForFilter($arrayOfImportIds));
+        $this->view->assign('filter', $this->filter);
+        $this->view->assign('cities', $this->ortRepository->findAll());
+        return $this->view->render();
+    }
+
     /**
      * Action for Standard List View
      */
@@ -512,39 +542,40 @@ class BaseController extends ActionController
 
     protected function generateCityAndDistrictStructureForFilter()
     {
-        $cityAndDistrictStructure = [];
-
-        foreach ($this->ortRepository->findAll() as $city) {
-            /**
-             * @var $city Ort
-             */
-            $city_qtys = is_null($city->getAnzahlImmobilienArray()) ? array() : $city->getAnzahlImmobilienArray();
-            $city_qty = in_array('WOHNUNG', array_keys($city_qtys)) ? $city_qtys['WOHNUNG'] : 0;
-            $newCity = [
-                'caption' => $city->getBezeichner(),
-                'uid' => $city->getUid(),
-                'qty' => $city_qty
-            ];
-            if (count($city->getStadtteile()) > 0) {
-                $newDistricts = [];
-                foreach ($city->getStadtteile() as $district) {
-                    /**
-                     * @var $district Stadtteil
-                     */
-                    $district_qtys = is_null($city->getAnzahlImmobilienArray()) ? array() : $city->getAnzahlImmobilienArray();
-                    $district_qty = in_array('WOHNUNG', array_keys($district_qtys)) ? $district_qtys['WOHNUNG'] : 0;
-                    $newDistrict = [
-                        'caption' => $district->getBezeichner(),
-                        'uid' => $district->getUid(),
-                        'qty' => $district_qty
-                    ];
-                    $newDistricts[] = $newDistrict;
-                }
-                $newCity['districts'] = $newDistricts;
-            }
-            $cityAndDistrictStructure[] = $newCity;
-        }
-        return $cityAndDistrictStructure;
+//        $cityAndDistrictStructure = [];
+//
+//        foreach ($this->ortRepository->findAll() as $city) {
+//            /**
+//             * @var $city Ort
+//             */
+//            $city_qtys = is_null($city->getAnzahlImmobilienArray()) ? array() : $city->getAnzahlImmobilienArray();
+//            $city_qty = in_array('WOHNUNG', array_keys($city_qtys)) ? $city_qtys['WOHNUNG'] : 0;
+//            $newCity = [
+//                'caption' => $city->getBezeichner(),
+//                'uid' => $city->getUid(),
+//                'qty' => $city_qty
+//            ];
+//            if (count($city->getStadtteile()) > 0) {
+//                $newDistricts = [];
+//                foreach ($city->getStadtteile() as $district) {
+//                    /**
+//                     * @var $district Stadtteil
+//                     */
+//                    $district_qtys = is_null($city->getAnzahlImmobilienArray()) ? array() : $city->getAnzahlImmobilienArray();
+//                    $district_qty = in_array('WOHNUNG', array_keys($district_qtys)) ? $district_qtys['WOHNUNG'] : 0;
+//                    $newDistrict = [
+//                        'caption' => $district->getBezeichner(),
+//                        'uid' => $district->getUid(),
+//                        'qty' => $district_qty
+//                    ];
+//                    $newDistricts[] = $newDistrict;
+//                }
+//                $newCity['districts'] = $newDistricts;
+//            }
+//            $cityAndDistrictStructure[] = $newCity;
+//        }
+//        return $cityAndDistrictStructure;
+        return $this->generateCityAndDistrictUniversal('array');
     }
 
     /**
@@ -663,22 +694,25 @@ class BaseController extends ActionController
                             e.datei AS image, 
                             f.identifier
                         FROM tx_sgestatecore_domain_model_immobilie AS a
-                        LEFT JOIN tx_sgestatecore_domain_model_stadtteil AS b ON a.objekt_stadtteil = b.uid 
-                        LEFT JOIN tx_sgestatecore_domain_model_objektart AS c ON a.objektart = c.uid
-                        LEFT JOIN tx_sgestatecore_domain_model_ort AS d ON a.objekt_ort = d.uid 
-                        LEFT JOIN (
-                            SELECT immobilie, datei, typ 
-                            FROM tx_sgestatecore_domain_model_anhang 
-                            WHERE typ IN (1, 7) 
-                            GROUP BY immobilie 
-                            ORDER BY typ ASC, uid ASC
-                        ) AS e ON a.uid = e.immobilie  
-                        LEFT JOIN sys_file AS s ON s.name = e.datei
-                        LEFT JOIN sys_file_processedfile AS f ON 
-                            s.uid = f.original 
-                            AND task_type = 'Image.CropScaleMask' 
-                            AND width = " . $cw . "
-                            AND height = " .$ch;
+                            LEFT JOIN tx_sgestatecore_domain_model_stadtteil AS b ON a.objekt_stadtteil = b.uid 
+                            LEFT JOIN tx_sgestatecore_domain_model_objektart AS c ON a.objektart = c.uid
+                            LEFT JOIN tx_sgestatecore_domain_model_ort AS d ON a.objekt_ort = d.uid 
+                            LEFT JOIN (
+                                SELECT immobilie, datei, typ 
+                                FROM tx_sgestatecore_domain_model_anhang 
+                                WHERE typ IN (1, 7) 
+                                GROUP BY immobilie 
+                                ORDER BY typ ASC, uid ASC
+                            ) AS e ON a.uid = e.immobilie  
+                            LEFT JOIN sys_file AS s ON s.name = e.datei
+                            LEFT JOIN sys_file_processedfile AS f ON 
+                                s.uid = f.original 
+                                AND task_type = 'Image.CropScaleMask' 
+                                AND width = " . $cw . "
+                                AND height = " .$ch. " 
+                        WHERE a.deleted = 0 
+                        AND a.hidden = 0;";
+
                     $connection = GeneralUtility::makeInstance(ConnectionPool::class)->getConnectionByName('Default');
                     $allRealties = $connection->createQueryBuilder()->addSelectLiteral($sql)->execute()->fetchAll();
                     $arrayReturn = ['realties' => []];
@@ -1740,4 +1774,77 @@ class BaseController extends ActionController
         return $presets;
     }
 
+    public function presetsAction() {
+        // $this->view->assign('cities', $this->ortRepository->findAll());
+        $this->view->assign('cities', $this->generateCityAndDistrictUniversal('object'));
+        $entry = $this->view->render();
+        return $entry;
+    }
+
+    protected function generateCityAndDistrictUniversal($type='array')
+    {
+        $cityAndDistrictStructure = [];
+        $sql = "a.`uid`, 
+        a.`bezeichner`, 
+        a.`anzahl_immobilien`, 
+        a.`fuer_suche_verwenden`, 
+        a.`pid`,
+        GROUP_CONCAT(CONCAT('{uid:|', b.`uid`, '|, pid:|', b.`pid`, '|, bezeichner:|', b.`bezeichner`, '|, fuer_suche_verwenden:|', b.`fuer_suche_verwenden`, '|}')) AS `stadtteile` 
+        FROM `tx_sgestatecore_domain_model_stadtteil` AS b 
+        INNER JOIN `tx_sgestatecore_domain_model_ort` AS a 
+        ON b.`ort` = a.`uid` 
+        GROUP BY b.`ort`";
+        $connection = GeneralUtility::makeInstance(ConnectionPool::class)->getConnectionByName('Default');
+        $cities = $connection->createQueryBuilder()->addSelectLiteral(str_replace('|', '"', $sql))->execute()->fetchAll();
+        foreach ($cities as $city) {
+            $city_qtys  = is_null($city['anzahl_immobilien']) ? array() : json_decode($city['anzahl_immobilien'], true);
+            $city_qty   = in_array('WOHNUNG', array_keys($city_qtys)) ? $city_qtys['WOHNUNG'] : 0;
+            $districts  = !empty($city['stadtteile']) ? json_decode($city['stadtteile'], true) : array();
+            if($type != 'array') {
+                $newCity = GeneralUtility::makeInstance(Ort::class);
+                $newCity->_setProperty('uid', $city['uid']);
+                $newCity->_setProperty('pid', $city['pid']);
+                $newCity->_setProperty('bezeichner', $city['bezeichner']);
+                $newCity->_setProperty('fuer_suche_verwenden', $city['fuer_suche_verwenden']);
+                $newCity->_setProperty('anzahlImmobilien', $city['anzahl_immobilien']);
+                if (is_array($districts) && count($districts) > 0) {
+                    $newDistricts = [];
+                    foreach ($districts as $district) {
+                        $newDistrict = GeneralUtility::makeInstance(Stadtteil::class);
+                        $newDistrict->_setProperty('uid', $district['uid']);
+                        $newDistrict->_setProperty('pid', $district['pid']);
+                        $newDistrict->_setProperty('bezeichner', $district['bezeichner']);
+                        $newDistrict->_setProperty('fuer_suche_verwenden', $district['fuer_suche_verwenden']);
+                        $newDistricts[] = $newDistrict;
+                    }
+                    $newCity->_setProperty('stadtteile', $newDistricts);
+                }
+            } else {
+
+                $newCity = [
+                    'caption' => $city['bezeichner'],
+                    'uid' => $city['uid'],
+                    'qty' => $city_qty
+                ];
+
+                if (is_array($districts) && count($districts) > 0) {
+                    $newDistricts = [];
+                    foreach ($districts as $district) {
+                        $newDistrict = [
+                            'caption' => $district['bezeichner'],
+                            'uid' => $district['uid'],
+                            'qty' => $city_qty
+                        ];
+                        $newDistricts[] = $newDistrict;
+                    }
+
+                    $newCity['districts'] = $newDistricts;
+                }
+            }
+            $cityAndDistrictStructure[] = $newCity;
+        }
+;
+        return $cityAndDistrictStructure;
+    }
+    
 }
